@@ -16,20 +16,18 @@
  *along with this program; if not, write to the Free Software
  *Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
-/*$Id: MindMapLine.java,v 1.2 2003/11/29 17:12:33 christianfoltin Exp $*/
+/*$Id: MindMapLine.java,v 1.2.34.2 2007/08/21 19:54:08 christianfoltin Exp $*/
 
 package freemind.modes;
 
 import java.awt.Color;
-import java.awt.Stroke;
-import freemind.modes.MindMapNode;
 
 public interface MindMapLine extends Cloneable {
 
     public Color getColor();
     public String getStyle();
-    public Stroke getStroke();
     public int getWidth();
+    public int getRealWidth();
     public String toString();
     /** The node to which this line is associated. */
     public void setTarget(MindMapNode node);
