@@ -16,17 +16,15 @@
  *along with this program; if not, write to the Free Software
  *Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
-/*$Id: MindMapEdgeModel.java,v 1.9 2003/11/03 11:00:20 sviles Exp $*/
+/*$Id: MindMapEdgeModel.java,v 1.9.18.2 2004/10/28 05:24:54 christianfoltin Exp $*/
 
 package freemind.modes.mindmapmode;
 
 import freemind.main.FreeMindMain;
-import freemind.modes.MindMapNode;
-import freemind.modes.EdgeAdapter;
 import freemind.main.Tools;
-import java.awt.Color;
-
 import freemind.main.XMLElement;
+import freemind.modes.EdgeAdapter;
+import freemind.modes.MindMapNode;
 
 public class MindMapEdgeModel extends EdgeAdapter {
 
@@ -34,37 +32,4 @@ public class MindMapEdgeModel extends EdgeAdapter {
 	super(node,frame);
     }
 
-    public XMLElement save() {
-	if (style!=null || color!=null || width!=WIDTH_PARENT) {
-	    XMLElement edge = new XMLElement();
-	    edge.setName("edge");
-
-	    if (style != null) {
-		edge.setAttribute("style",style);
-	    }
-	    if (color != null) {
-		edge.setAttribute("color",Tools.colorToXml(color));
-	    }
-	    if (width != WIDTH_PARENT) {
-		    if (width == WIDTH_THIN)
-				edge.setAttribute("width","thin");
-			else
-				edge.setAttribute("width",Integer.toString(width));
-	    }
-	    return edge;
-	}
-	return null;
-    }
-
-    public void setColor(Color color) {
-	super.setColor(color);
-    }
-
-    public void setWidth(int width) {
-	super.setWidth(width);
-    }
-
-    public void setStyle(String style) {
-	super.setStyle(style);
-    }
 }
